@@ -1,8 +1,8 @@
 `findSubsets` <-
 function(noflevels, row.no, maximum) {
-    if (missing(maximum)) maximum <- prod(noflevels + 1)
-    mbaserow <- getRow(noflevels + 1, row.no)
-    mbase <- rev(c(1, cumprod(rev(noflevels + 1))))[-1]
+    if (missing(maximum)) maximum <- prod(noflevels)
+    mbaserow <- getRow(noflevels, row.no)
+    mbase <- rev(c(1, cumprod(rev(noflevels))))[-1]
     
     increment <- function(x, y, cond.levels) {
         a <- x
